@@ -1,16 +1,29 @@
 # -*- coding: utf-8 -*-
 #------------------------------------------------------------------------------
 # file: $Id$
-# lib:  svnpublish.engine
-# desc: unit test for "fingerprint" svnpublish engine module
-# auth: griffin <griffin@uberdev.org>
+# auth: metagriffin <mg.github@uberdev.org>
 # date: 2011/05/15
-# copy: (C) CopyLoose 2011 UberDev <hardcore@uberdev.org>, No Rights Reserved.
+# copy: (C) Copyright 2011-EOT metagriffin -- see LICENSE.txt
+#------------------------------------------------------------------------------
+# This software is free software: you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This software is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see http://www.gnu.org/licenses/.
+#------------------------------------------------------------------------------
+
 #------------------------------------------------------------------------------
 # TODO: currently, this unit test actually writes to disk - this should be fixed
-#      so that it uses the FileSystemOverlay... unfortunately that is a
-#      monumental task, since the "export" engine relies heavily on system
-#      calls.... ugh.
+#       so that it uses the FileSystemOverlay... unfortunately that is a
+#       monumental task, since the "export" engine relies heavily on system
+#       calls.... ugh.
 # TODO: use FSO!
 #------------------------------------------------------------------------------
 
@@ -168,6 +181,40 @@ publish:
       svnrev.svnlook('cat', 'content/textfile.txt'))
     self.assertEqual(fs['/fp.json']['content'], 'rev4.0')
 
+  #----------------------------------------------------------------------------
+  def test_fingerprint_defaultpath(self):
+    svnrev   = revinfo.RevisionInfo(subversion.Subversion(self.svnRepos), '4')
+    tmpdir   = self.tmpdir
+    self.options.configOrder = ['all']
+    self.options.publishOnly = ['content']
+    registerAllConfig('all', '''\
+publish:
+  - engine: export
+    incremental: false
+    path: ''' + tmpdir + '''
+    fixate:
+      - { engine: fingerprint, format: \'rev%(revision)s.0\' }
+''')
+    svnpub = framework.Framework(self.options, svnrev=svnrev)
+    self.log.setLevel(logging.DEBUG)
+    errcnt = svnpub.run()
+    self.assertEqual(errcnt, 0, 'svnpublish did not execute cleanly: ' + self.logput.getvalue())
+    fs = loadFileSystem(self.tmpdir, True)
+    self.assertEqual(
+      sorted([':'.join([e.type, e.path]) for e in fs.values()]),
+      sorted(['dir:/directory',
+              'file:/directory/textfile.txt',
+              'file:/fingerprint',
+              'file:/textfile.txt',
+              ]))
+    self.assertMultiLineEqual(
+      fs['/directory/textfile.txt']['content'],
+      svnrev.svnlook('cat', 'content/directory/textfile.txt'))
+    self.assertMultiLineEqual(
+      fs['/textfile.txt']['content'],
+      svnrev.svnlook('cat', 'content/textfile.txt'))
+    self.assertEqual(fs['/fingerprint']['content'], 'rev4.0')
+
 #------------------------------------------------------------------------------
 # end of $Id$
 #------------------------------------------------------------------------------
